@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2014-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2014-2016 -- leonerd@leonerd.org.uk
 
 package Device::Chip::INA219;
 
@@ -12,7 +12,7 @@ use base qw( Device::Chip );
 
 use utf8;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Carp;
 use Data::Bitfield qw( bitfield boolfield enumfield );
@@ -25,6 +25,16 @@ use constant PROTOCOL => "I2C";
 
 C<Device::Chip::INA219> - chip driver for an F<INA219>
 
+=head1 SYNOPSIS
+
+ use Device::Chip::INA219;
+
+ my $chip = Device::Chip::INA219->new;
+ $chip->mount( Device::Chip::Adapter::...->new )->get;
+
+ printf "Current bus voltage is %d mV, shunt voltage is %d uV\n",
+    $chip->read_bus_voltage->get, $chip->read_shunt_voltage->get;
+
 =head1 DESCRIPTION
 
 This L<Device::Chip> subclass provides specific communication to a
@@ -106,7 +116,7 @@ bitfield CONFIG =>
 
 =head2 read_config
 
-   $config = $ina->read_config->get
+   $config = $chip->read_config->get
 
 Reads and returns the current chip configuration as a C<HASH> reference.
 
@@ -133,7 +143,7 @@ sub _config
 
 =head2 change_config
 
-   $ina->change_config( %config )->get
+   $chip->change_config( %config )->get
 
 Changes the configuration. Any field names not mentioned will be preserved.
 
@@ -154,7 +164,7 @@ sub change_config
 
 =head2 read_shunt_voltage
 
-   $uv = $ina->read_shunt_voltage->get
+   $uv = $chip->read_shunt_voltage->get
 
 Returns the current shunt voltage reading scaled integer in microvolts.
 
@@ -174,9 +184,9 @@ sub read_shunt_voltage
 
 =head2 read_bus_voltage
 
-   $mv = $ina->read_bus_voltage->get
+   $mv = $chip->read_bus_voltage->get
 
-   ( $mv, $ovf, $cnvr ) = $ina->read_bus_voltage->get
+   ( $mv, $ovf, $cnvr ) = $chip->read_bus_voltage->get
 
 Returns the current bus voltage reading, as a scaled integer in milivolts.
 
